@@ -44,6 +44,7 @@ static struct gpe_icon my_icons[] = {
 	{ "treble" , PREFIX "/share/gpe-mixer/treble.png"},
 	{ "synth" , PREFIX "/share/gpe-mixer/synth.png"},
 	{ "speaker" , PREFIX "/share/gpe-mixer/speaker.png"},
+	{ "phout" , PREFIX "/share/gpe-mixer/speaker.png"},
 	{ "pcm" , PREFIX "/share/gpe-mixer/pcm.png"},
 	{ "pcm2" , PREFIX "/share/gpe-mixer/pcm.png"},
 	{ "mic" , PREFIX "/share/gpe-mixer/mic.png"},
@@ -63,7 +64,7 @@ gchar **channels = NULL;
 /* mixer handling */
 char *mixer_labels[SOUND_MIXER_NRDEVICES] = SOUND_DEVICE_LABELS;
 char *mixer_names[SOUND_MIXER_NRDEVICES] = SOUND_DEVICE_NAMES;
-int devmask = 0, recmask = 0, recsrc = 0;
+int devmask = 0;
 int mixfd;
 
 static gboolean 
@@ -253,14 +254,6 @@ gchar *cstr = NULL;
 		gpe_perror_box("SOUND_MIXER_READ_DEVMASK");
 		exit(1);
 	}
-	if (ioctl(mixfd, SOUND_MIXER_READ_RECMASK, &recmask) == -1) {
-		gpe_perror_box("SOUND_MIXER_READ_RECMASK");
-		exit(1);
-	}
-	if (ioctl(mixfd, SOUND_MIXER_READ_RECSRC, &recsrc) == -1) {
-		gpe_perror_box("SOUND_MIXER_READ_RECSRC");
-		exit(1);
-	}
 
 	/* GTK Window stuff */
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
